@@ -5,6 +5,7 @@ from SciDataTool.Functions.Plot import (
     axes_dict,
     COLORS,
 )
+from SciDataTool.Functions.Load.import_class import import_class
 from numpy import (
     squeeze,
     split,
@@ -126,6 +127,9 @@ def plot_2D_Data(
         True to display legend in a frame
     """
 
+    # Dynamic import to avoid import loop
+    DataPattern = import_class("SciDataTool.Classes", "DataPattern")
+
     # Extract arg_list it the function called from another script with *arg_list
     if len(arg_list) == 1 and type(arg_list[0]) == tuple:
         arg_list = arg_list[0]
@@ -221,7 +225,7 @@ def plot_2D_Data(
 
     # Build xlabel and title parts 2 and 3
     title2 = ""
-    title3 = " for "
+    title3 = "for "
     for axis in axes_list:
         # Title part 2
         if axis.unit in norm_dict:
@@ -243,7 +247,7 @@ def plot_2D_Data(
             and len(axis.values) > 1
             or (len(axis.values) == 1 and len(axes_list) == 1)
         ):
-            title2 = "over " + name.lower()
+            # title2 = "over " + name.lower()
             if axis.unit == "SI":
                 if axis.name in unit_dict:
                     axis_unit = unit_dict[axis.name]
@@ -278,43 +282,55 @@ def plot_2D_Data(
             else:
                 xticklabels = None
         else:
-            if axis.unit == "SI":
-                if axis.name in unit_dict:
-                    axis_unit = unit_dict[axis.name]
+            is_display = True
+            if axis.is_pattern and len(axis.values) == 1:
+                is_display = False
+            if is_display:
+                if axis.unit == "SI":
+                    if axis.name in unit_dict:
+                        axis_unit = unit_dict[axis.name]
+                    else:
+                        axis_unit = axis.unit
+                elif axis.unit in norm_dict:
+                    axis_unit = norm_dict[axis.unit]
                 else:
                     axis_unit = axis.unit
-            elif axis.unit in norm_dict:
-                axis_unit = norm_dict[axis.unit]
-            else:
-                axis_unit = axis.unit
 
-            if isinstance(result_0[axis.name], str):
-                title3 += name + "=" + result_0[axis.name]
-            else:
-                axis_str = array2string(
-                    result_0[axis.name], formatter={"float_kind": "{:.3g}".format}
-                ).replace(" ", ", ")
-                if len(result_0[axis.name]) == 1:
-                    axis_str = axis_str.strip("[]")
+                if isinstance(result_0[axis.name], str):
+                    title3 += name + "=" + result_0[axis.name]
+                else:
+                    axis_str = array2string(
+                        result_0[axis.name], formatter={"float_kind": "{:.3g}".format}
+                    ).replace(" ", ", ")
+                    if len(result_0[axis.name]) == 1:
+                        axis_str = axis_str.strip("[]")
 
-                title3 += name + "=" + axis_str.rstrip(", ") + " [" + axis_unit + "], "
+                    title3 += (
+                        name + "=" + axis_str.rstrip(", ") + " [" + axis_unit + "], "
+                    )
 
     # Title part 4 containing axes that are here but not involved in requested axes
     title4 = ""
     for axis_name in axes_dict_other:
-        title4 += (
-            axis_name
-            + "="
-            + array2string(
-                axes_dict_other[axis_name][0],
-                formatter={"float_kind": "{:.3g}".format},
-            ).replace(" ", ", ")
-            + " ["
-            + axes_dict_other[axis_name][1]
-            + "], "
-        )
+        is_display = True
+        for axis in self.axes:
+            if axis.name == axis_name:
+                if isinstance(axis, DataPattern) and len(axis.unique_indices) == 1:
+                    is_display = False
+        if is_display:
+            title4 += (
+                axis_name
+                + "="
+                + array2string(
+                    axes_dict_other[axis_name][0],
+                    formatter={"float_kind": "{:.3g}".format},
+                ).replace(" ", ", ")
+                + " ["
+                + axes_dict_other[axis_name][1]
+                + "], "
+            )
 
-    if title3 == " for " and title4 == "":
+    if title3 == "for " and title4 == "":
         title3 = ""
 
     if title is None:
@@ -330,7 +346,7 @@ def plot_2D_Data(
 
     # Detect how many curves are overlaid, build legend and color lists
     if legend_list == [] and data_list != []:
-        legend_list = ["[" + d.name + "] " for d in data_list2]
+        legend_list = [d.name for d in data_list2]
     elif legend_list == []:
         legend_list = ["" for d in data_list2]
     # else:
@@ -465,17 +481,25 @@ def plot_2D_Data(
         xticks = unique(insert(freqs[indices], 0, 0))
 
         if is_auto_range:
-            if len(xticks) > 0:
+            if len(xticks) > 1:
                 if x_min is None:
-                    x_min = -xticks[-1] * 0.1
+                    x_min = xticks[0]
                 if x_max is None:
-                    x_max = xticks[-1] * 1.1
+                    x_max = xticks[-1]
+            else:
+                if x_min is None:
+                    x_min = np_min(freqs)
+                if x_max is None:
+                    x_max = np_max(freqs)
         else:
             if x_min is None:
                 x_min = np_min(freqs)
             if x_max is None:
                 x_max = np_max(freqs)
 
+        x_min = x_min - x_max * 0.05
+        x_max = x_max * 1.05
+
         if not is_auto_ticks:
             xticks = None
 
