@@ -1,8 +1,10 @@
 from SciDataTool.Functions.Plot.plot_4D import plot_4D
 from SciDataTool.Functions.Plot.plot_3D import plot_3D
 from SciDataTool.Functions.Plot import unit_dict, norm_dict, axes_dict
+from SciDataTool.Functions.Load.import_class import import_class
 from SciDataTool.Classes.Norm_indices import Norm_indices
 from numpy import (
+    any as np_any,
     where,
     meshgrid,
     unique,
@@ -112,6 +114,9 @@ def plot_3D_Data(
         to switch x and y axes
     """
 
+    # Dynamic import to avoid import loop
+    DataPattern = import_class("SciDataTool.Classes", "DataPattern")
+
     if len(arg_list) == 1 and type(arg_list[0]) == tuple:
         arg_list = arg_list[0]  # if called from another script with *arg_list
 
@@ -192,14 +197,6 @@ def plot_3D_Data(
         X_flat = X_map.flatten()
         Y_flat = Y_map.flatten()
         Z_flat = Zdata.flatten()
-    if x_min is None:
-        x_min = np_min(Xdata)
-    if x_max is None:
-        x_max = np_max(Xdata)
-    if y_min is None:
-        y_min = np_min(Ydata)
-    if y_max is None:
-        y_max = np_max(Ydata)
     if z_range is None:
         if z_min is None:
             z_min = np_min(Zdata)
@@ -219,7 +216,7 @@ def plot_3D_Data(
         name = axes_dict[axis.name]
     else:
         name = axis.name
-    title2 = "over " + name.lower()
+    # title2 = "over " + name.lower()
     if axis.unit == "SI":
         axis_unit = unit_dict[axis.name]
         if xlabel is None:
@@ -239,8 +236,8 @@ def plot_3D_Data(
         xticks = [i * round(np_max(axis.values) / 6) for i in range(7)]
     else:
         xticks = None
-    if axis.is_components:
-        xticklabels = result[axes_list[0].name]
+    if axis.is_components and axis.extension != "list":
+        xticklabels = result[axis.name]
         xticks = Xdata
     else:
         xticklabels = None
@@ -250,7 +247,7 @@ def plot_3D_Data(
         name = axes_dict[axis.name]
     else:
         name = axis.name
-    title3 = " and " + axis.name.lower()
+    # title3 = " and " + axis.name.lower()
     if axis.unit == "SI":
         axis_unit = unit_dict[axis.name]
         if ylabel is None:
@@ -270,9 +267,9 @@ def plot_3D_Data(
         yticks = [i * round(np_max(axis.values) / 6) for i in range(7)]
     else:
         yticks = None
-    if axis.is_components:
-        yticklabels = result[axes_list[1].name]
-        yticks = Xdata
+    if axis.is_components and axis.extension != "list":
+        yticklabels = result[axis.name]
+        yticks = Ydata
     else:
         yticklabels = None
 
@@ -288,60 +285,65 @@ def plot_3D_Data(
                 is_shading_flat = True
                 flat_indices.append(axis.index)
 
-    if is_shading_flat:
-        type_plot = "pcolormesh"
-        # 0.5 offset
-        if 0 in flat_indices:
-            Xdata = Xdata - 0.5
-            x_min -= 0.5
-            x_max -= 0.5
-        if 1 in flat_indices:
-            Ydata = Ydata - 0.5
-            y_min -= 0.5
-            y_max -= 0.5
-        Ydata, Xdata = meshgrid(Ydata, Xdata)
-
-    title4 = " for "
+    title4 = "for "
     for axis in axes_list[2:]:
-        if axis.unit == "SI":
-            axis_unit = unit_dict[axis.name]
-        elif axis.unit in norm_dict:
-            axis_unit = norm_dict[axis.unit]
-        else:
-            axis_unit = axis.unit
-        title4 += (
-            axis.name
-            + "="
-            + array2string(
-                result[axis.name],
-                formatter={"float_kind": "{:.3g}".format},
-            )
-            .replace(" ", ", ")
-            .replace("[", "")
-            .replace("]", "")
-            + " ["
-            + axis_unit
-            + "], "
-        )
+        is_display = True
+        if axis.is_pattern and len(axis.values) == 1:
+            is_display = False
+        if is_display:
+            if axis.unit == "SI":
+                axis_unit = unit_dict[axis.name]
+            elif axis.unit in norm_dict:
+                axis_unit = norm_dict[axis.unit]
+            else:
+                axis_unit = axis.unit
+
+            if isinstance(result[axis.name], str):
+                axis_str = result[axis.name]
+            else:
+                axis_str = (
+                    array2string(
+                        result[axis.name],
+                        formatter={"float_kind": "{:.3g}".format},
+                    )
+                    .replace(" ", ", ")
+                    .replace("[", "")
+                    .replace("]", "")
+                    + " ["
+                    + axis_unit
+                    + "], "
+                )
+
+            title4 += axis.name + "=" + axis_str
+
     title5 = ""
     for axis_name in axes_dict_other:
-        title5 += (
-            axis_name
-            + "="
-            + array2string(
-                axes_dict_other[axis_name][0],
-                formatter={"float_kind": "{:.3g}".format},
-            ).replace(" ", ", ")
-            + " ["
-            + axes_dict_other[axis_name][1]
-            + "], "
-        )
+        is_display = True
+        for axis in self.axes:
+            if axis.name == axis_name:
+                if isinstance(axis, DataPattern) and len(axis.unique_indices) == 1:
+                    is_display = False
+        if is_display:
+            if isinstance(axes_dict_other[axis_name][0], str):
+                axis_str = axes_dict_other[axis_name][0]
+            else:
+                axis_str = (
+                    array2string(
+                        axes_dict_other[axis_name][0],
+                        formatter={"float_kind": "{:.3g}".format},
+                    ).replace(" ", ", ")
+                    + " ["
+                    + axes_dict_other[axis_name][1]
+                    + "], "
+                )
 
-    if title4 == " for " and title5 == "":
+            title5 += axis_name + "=" + axis_str
+
+    if title4 == "for " and title5 == "":
         title4 = ""
 
     if title is None:
-        title = title1 + title2 + title3 + title4 + title5
+        title = title1 + title4 + title5
         title = title.rstrip(", ")
 
     if is_fft:
@@ -353,24 +355,60 @@ def plot_3D_Data(
                 thresh = 0.02
 
         if "dB" in unit:
-            indices = where(Z_flat > 10 * log10(thresh) + abs(np_max(Zdata)))[0]
+            indices_x = np_any(
+                where(Zdata > 10 * log10(thresh) + abs(np_max(Zdata)), True, False),
+                axis=1,
+            )
+            indices_y = np_any(
+                where(Zdata > 10 * log10(thresh) + abs(np_max(Zdata)), True, False),
+                axis=0,
+            )
         else:
-            indices = where(Z_flat > abs(thresh * np_max(Zdata)))[0]
+            indices_x = np_any(
+                where(Zdata > abs(thresh * np_max(Zdata)), True, False), axis=1
+            )
+            indices_y = np_any(
+                where(Zdata > abs(thresh * np_max(Zdata)), True, False), axis=0
+            )
 
-        xticks = unique(X_flat[indices])
-        yticks = unique(Y_flat[indices])
+        xticks = Xdata[indices_x]
+        yticks = Ydata[indices_y]
         if is_auto_range:
-            if len(xticks) > 0:
-                x_min = -0.1 * xticks[-1]
-                x_max = xticks[-1] * 1.1
-            if len(yticks) > 0:
-                y_min = yticks[0] * 1.1
-                y_max = yticks[-1] * 1.1
+            if len(xticks) > 1:
+                if x_min is None:
+                    x_min = xticks[0]
+                if x_max is None:
+                    x_max = xticks[-1]
+            else:
+                if x_min is None:
+                    x_min = np_min(Xdata)
+                if x_max is None:
+                    x_max = np_max(Xdata)
+            if len(yticks) > 1:
+                if y_min is None:
+                    y_min = yticks[0]
+                if y_max is None:
+                    y_max = yticks[-1]
+            else:
+                if y_min is None:
+                    y_min = np_min(Ydata)
+                if y_max is None:
+                    y_max = np_max(Ydata)
         else:
-            x_min = x_min - x_max * 0.05
-            x_max = x_max * 1.05
-            y_min = y_min - y_max * 0.2
-            y_max = y_max * 1.2
+            if x_min is None:
+                x_min = np_min(Xdata)
+            if x_max is None:
+                x_max = np_max(Xdata)
+            if y_min is None:
+                y_min = np_min(Ydata)
+            if y_max is None:
+                y_max = np_max(Ydata)
+
+        x_min = x_min - x_max * 0.05
+        x_max = x_max * 1.05
+        y_min = y_min - y_max * 0.2
+        y_max = y_max * 1.2
+
         if not is_auto_ticks:
             xticks = None
             yticks = None
@@ -451,6 +489,26 @@ def plot_3D_Data(
             )
     else:
         if is_2D_view:
+            if is_shading_flat:
+                if x_min is None:
+                    x_min = np_min(Xdata)
+                if x_max is None:
+                    x_max = np_max(Xdata)
+                if y_min is None:
+                    y_min = np_min(Ydata)
+                if y_max is None:
+                    y_max = np_max(Ydata)
+                type_plot = "pcolormesh"
+                # 0.5 offset
+                if 0 in flat_indices:
+                    Xdata = Xdata - 0.5
+                    x_min -= 0.5
+                    x_max -= 0.5
+                if 1 in flat_indices:
+                    Ydata = Ydata - 0.5
+                    y_min -= 0.5
+                    y_max -= 0.5
+                Ydata, Xdata = meshgrid(Ydata, Xdata)
             plot_3D(
                 Xdata,
                 Ydata,
